#
# spec file for package ghc-vault
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name vault
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        0.3.1.5
Release:        6.2
Summary:        A persistent store for values of arbitrary types
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/5.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashable-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-unordered-containers-prof
ExcludeArch:    %{ix86}

%description
A /vault/ is a persistent store for values of arbitrary types. It's like having
first-class access to the storage space behind IORefs.

The data structure is analogous to a bank vault, where you can access different
bank boxes with different keys; hence the name.

Also provided is a /locker/ type, representing a store for a single element.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Tue Oct 24 2023 Peter Simons <psimons@suse.com>
- Update vault to version 0.3.1.5 revision 5.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Oct  7 2023 Peter Simons <psimons@suse.com>
- Update vault to version 0.3.1.5 revision 4.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Mar 14 2023 Peter Simons <psimons@suse.com>
- Update vault to version 0.3.1.5 revision 3.
  Upstream has revised the Cabal build instructions on Hackage.
* Tue Aug  9 2022 Peter Simons <psimons@suse.com>
- Update vault to version 0.3.1.5 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Wed Nov  3 2021 psimons@suse.com
- Update vault to version 0.3.1.5 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Feb 20 2021 psimons@suse.com
- Update vault to version 0.3.1.5.
  * *0.3.1.5**
  * Compatibility with GHC-9.0
  * Bump dependencies to allow `base >= 4.5 && < 4.16`
  * Depend on `semigroups` only with `GHC < 8.0`
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add vault at version 0.3.1.4.
